.. Copyright NTESS. See COPYRIGHT file for details.

   SPDX-License-Identifier: MIT

.. _usage:

canary usage
============

.. note::

   Many of the code-snippets and output in the documentation were auto-generated using a set of examples distributed with ``canary``'s source code.  To run the examples, clone the ``canary`` repository and navigate to ``tests/examples`` where all of the examples in the guide are run.

.. toctree::
   :maxdepth: 1

   usage.finding_tests
   usage.describe
   usage.run
   usage.filter
   usage.parameterize
   usage.status
   usage.log
   usage.rerun
   usage.rebaseline
   usage.location
   usage.enable
   usage.copy_and_link
   usage.execute_and_analyze
   usage.xstatus
   usage.modules
   usage.rcfiles
